@@ -1,4 +1,4 @@
-import by as _by
+from . import by as _by
 
 class PitchTier(object):
     """A PitchTier."""
